import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ExpressVO, ExpressQuery, ExpressForm } from '@/api/workflow/express/types';

/**
 * 查询快递列表
 * @param query
 * @returns {*}
 */

export const listExpress = (query?: ExpressQuery): AxiosPromise<ExpressVO[]> => {
  return request({
    url: '/workflow/express/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询快递详细
 * @param id
 */
export const getExpress = (id: string | number): AxiosPromise<ExpressVO> => {
  return request({
    url: '/workflow/express/' + id,
    method: 'get'
  });
};

/**
 * 新增快递
 * @param data
 */
export const addExpress = (data: ExpressForm): AxiosPromise<ExpressVO> => {
  return request({
    url: '/workflow/express',
    method: 'post',
    data: data
  });
};

/**
 * 修改快递
 * @param data
 */
export const updateExpress = (data: ExpressForm): AxiosPromise<ExpressVO> => {
  return request({
    url: '/workflow/express',
    method: 'put',
    data: data
  });
};

/**
 * 删除快递
 * @param id
 */
export const delExpress = (id: string | number | Array<string | number>) => {
  return request({
    url: '/workflow/express/' + id,
    method: 'delete'
  });
};
